==> nextcloud-20.0.7-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/settings/l10n/oc.js <==
OC.L10N.register(
    "settings",
    {
    "Migration in progress. Please wait until the migration is finished" : "Migracion en cors. Mercés d’esperar fins que la migracion aja acabat",
    "Migration started …" : "Migracion començaca…",
    "Saved" : "Enregistrat",
    "Not saved" : "Pas enregistrat",
    "Sending…" : "Mandadís…",
    "Email sent" : "Corrièl mandat",
    "Private" : "Privat",
    "Don't synchronize to servers" : "Sincronizar pas als servidors",
    "Trusted" : "Fisable",
    "Only synchronize to trusted servers" : "Sincronizar pas qu’als servidors fisables",
    "Public" : "Public",
    "Synchronize to trusted servers and the global and public address book" : "Sincronizar als servidors fisables e los annuaris d’adreças globals e publics",
    "Verify" : "Verificar",
    "Verifying …" : "Verificacion…",
    "Unable to change password" : "Cambiament impossible del senhal",
    "Very weak password" : "Senhal plan feble",
    "Weak password" : "Senhal feble",
    "So-so password" : "Senhal mejan",
    "Good password" : "Bon senhal",
    "Strong password" : "Senhal fòrt",
    "An error occurred while changing your language. Please reload the page and try again." : "Una error s’es producha pendent lo cambiament de lenga. Mercés de recargar la pagina e tornar ensajar.",
    "An error occurred while changing your locale. Please reload the page and try again." : "Una error s’es producha pendent lo cambiament de varianta lingüistica. Mercés de recargar la pagina e tornar ensajar.",
    "Select a profile picture" : "Seleccionar un imatge de perfil",
    "Week starts on {fdow}" : "La setmana comença lo {fdow}",
    "Groups" : "Gropes",
    "Group list is empty" : "La lista de grop es voida",
    "Unable to retrieve the group list" : "Recuperacion de la lista de grops impossibla",
    "{actor} added you to group {group}" : "{actor} vos a apondut al grop {group}",
    "You added {user} to group {group}" : "Avètz apondut {user} al grop {group}",
    "You changed your password" : "Avètz cambiat de senhal",
    "Security" : "Seguretat",
    "Wrong password" : "Wrong password",
    "Invalid mail address" : "Adreça email invalida",
    "Settings saved" : "Paramètres enregistrats",
    "Welcome aboard" : "La benvenguda a bòrd",
    "Welcome aboard %s" : "La benvenguda a bòrd %s",
    "Your username is: %s" : "Vòstre nom d’utilizaire : %s",
    "Set your password" : "Definir vòstre senhal",
    "Go to %s" : "Anar a %s",
    "Install Client" : "Installar client",
    "Apps" : "Aplicacions",
    "Settings" : "Paramètres",
    "Personal" : "Personal",
    "Administration" : "Administracion",
    "Additional settings" : "Paramètres addicionals",
    "Overview" : "Apercebut",
    "Basic settings" : "Paramètres de basa",
    "Sharing" : "Partiment",
    "Personal info" : "Info personalas",
    "Mobile & desktop" : "Mobile e burèu",
    "Create" : "Crear",
    "Change" : "Modificar",
    "Delete" : "Suprimir",
    "Reshare" : "Repartir",
    "Unlimited" : "Illimitat",
    "Nextcloud settings" : "Paramètres Nextcloud",
    "Save changes" : "Enregistrar las modificacions",
    "All" : "Tot",
    "No results" : "Cap de resultat",
    "Update to {version}" : "Metre a jorn cap a {version}",
    "Remove" : "Suprimir",
    "Disable" : "Desactivar",
    "View in store" : "Veire a la botiga",
    "Visit website" : "Veire lo site web",
    "Report a bug" : "Raportar un bug",
    "User documentation" : "Documentacion utilizaire",
    "Admin documentation" : "Documentacion d’admin",
    "Developer documentation" : "Documentacion desvolopaire",
    "Update all" : "Tot metre a jorn",
    "Disable all" : "Desactivar tot",
    "Enable all" : "Activar tot",
    "Device settings" : "Paramètres periferic",
    "Allow filesystem access" : "Permetre accès filesystem",
    "Rename" : "Renomenar",
    "Revoke" : "Revocar",
    "Wipe device" : "Tirar periferic",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome per Android",
    "iPhone" : "iPhone",
    "iPad" : "iPad",
    "Nextcloud iOS app" : "Aplicacion Nextcloud iOS",
    "Nextcloud Talk for iOS" : "Nextcloud Talk per iOS",
    "Nextcloud Talk for Android" : "Nextcloud Talk per Android",
    "This session" : "Aquesta session",
    "Device" : "Periferic",
    "Last activity" : "Darrièra activitat",
    "Devices & sessions" : "Periferics e sessions",
    "Username" : "Nom d'utilizaire",
    "Password" : "Senhal",
    "Done" : "Done",
    "Copy" : "Copiar",
    "Cancel" : "Anullar",
    "Display name" : "Nom afichat",
    "Email" : "Adreça corrièl",
    "Default language" : "Lenga per defaut",
    "Close" : "Tampar",
    "Language" : "Lenga",
    "Common languages" : "Lengas comunas",
    "All languages" : "Totas las lengas",
    "Add" : "Ajustar",
    "Details" : "Detalhs",
    "Admins" : "Admins",
    "Show Languages" : "Veire las lengas",
    "Enable" : "Activar",
    "Never" : "Pas jamais",
    "Documentation" : "Documentacion",
    "None" : "Pas cap",
    "Login" : "Login",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Encryption" : "Chiframent",
    "Server address" : "Adreça del servidor",
    "Port" : "Pòrt",
    "Credentials" : "Informacions d'identificacion",
    "Save" : "Salvar",
    "Version" : "Version",
    "Enable encryption" : "Activar lo chiframent",
    "Start migration" : "Començar la migracion",
    "days" : "jorns",
    "Like our Facebook page" : "Aimar nòstra pagina Facebook",
    "Follow us on Twitter" : "Nos seguir sus Twitter",
    "Follow us on Mastodon" : "Nos seguir sus Mastodon",
    "Check out our blog" : "Donar un còp d’uèlh a nòstre blòg",
    "Subscribe to our newsletter" : "S’abonar a l’infoletra",
    "Profile picture" : "Imatge de perfil",
    "Upload new" : "Ne mandar un novèl",
    "Select from Files" : "Seleccionar dels fichièrs",
    "Remove image" : "Suprimir imatge",
    "png or jpg, max. 20 MB" : "png or jpg, max. 20 Mo",
    "Picture provided by original account" : "Imatge provesit pel compte d’origina",
    "Choose as profile picture" : "Causir coma imatge de perfil",
    "You are a member of the following groups:" : "Formatz part d’aquestes grops :",
    "You are using <strong>%s</strong>" : "Utilizatz <strong>%s</strong>",
    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Utilizatz <strong>%1$s</strong> de <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
    "Full name" : "Nom complèt",
    "No display name set" : "Cap de nom d’afichatge pas definit",
    "Your email address" : "Vòstra adreça electronica",
    "No email address set" : "Cap d’adreça pas definida",
    "Phone number" : "Numèro de telefòn",
    "Your phone number" : "Vòstre numèro de telefòn",
    "Address" : "Adreça",
    "Your postal address" : "Vòstra adreça postala",
    "Website" : "Site web",
    "Link https://…" : "Ligam https://…",
    "Twitter" : "Twitter",
    "Twitter handle @…" : "Escais Twitter @…",
    "Help translate" : "Ajudar a traduire",
    "Locale" : "Varianta lingüistica",
    "Current password" : "Senhal actual",
    "New password" : "Senhal novèl",
    "Change password" : "Cambiar de senhal",
    "Contacts" : "Contactes",
    "by" : "per",
    "Valid until" : "Valid fins a",
    "Issued By" : "Emés per",
    "Valid until %s" : "Valid fins a %s"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-21.0.1-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/settings/l10n/oc.js <==
OC.L10N.register(
    "settings",
    {
    "Migration in progress. Please wait until the migration is finished" : "Migracion en cors. Mercés d’esperar fins que la migracion aja acabat",
    "Migration started …" : "Migracion començada…",
    "Saved" : "Enregistrat",
    "Not saved" : "Pas enregistrat",
    "Sending…" : "Mandadís…",
    "Email sent" : "Corrièl mandat",
    "Private" : "Privat",
    "Only synchronize to trusted servers" : "Sincronizar pas qu’als servidors fisables",
    "Synchronize to trusted servers and the global and public address book" : "Sincronizar als servidors fisables e los annuaris d’adreças globals e publics",
    "Verify" : "Verificar",
    "Verifying …" : "Verificacion…",
    "Unable to change password" : "Cambiament impossible del senhal",
    "Very weak password" : "Senhal plan feble",
    "Weak password" : "Senhal feble",
    "So-so password" : "Senhal mejan",
    "Good password" : "Bon senhal",
    "Strong password" : "Senhal fòrt",
    "An error occurred while changing your language. Please reload the page and try again." : "Una error s’es producha pendent lo cambiament de lenga. Mercés de recargar la pagina e tornar ensajar.",
    "An error occurred while changing your locale. Please reload the page and try again." : "Una error s’es producha pendent lo cambiament de varianta lingüistica. Mercés de recargar la pagina e tornar ensajar.",
    "Select a profile picture" : "Seleccionar un imatge de perfil",
    "Week starts on {fdow}" : "La setmana comença lo {fdow}",
    "Groups" : "Gropes",
    "Group list is empty" : "La lista de grop es voida",
    "Unable to retrieve the group list" : "Recuperacion de la lista de grops impossibla",
    "{actor} added you to group {group}" : "{actor} vos a apondut al grop {group}",
    "You added {user} to group {group}" : "Avètz apondut {user} al grop {group}",
    "{actor} added {user} to group {group}" : "{actor} apondèt {user} al grop {group}",
    "An administrator added you to group {group}" : "Un administrator vos apondèt al grop {group}",
    "An administrator added {user} to group {group}" : "Un administrator apondèt {user} al grop {group}",
    "{actor} removed you from group {group}" : "{actor} vos levèt d’al grop {group}",
    "You removed {user} from group {group}" : "Levèretz {user} d’al grop {group}",
    "{actor} removed {user} from group {group}" : "{actor} levèt {user} d’al grop {group}",
    "An administrator removed you from group {group}" : "Un administrator vos levèt d’al grop {group}",
    "An administrator removed {user} from group {group}" : "Un administrator levèt {user} d’al grop {group}",
    "{actor} changed your password" : "{actor} a cambiat vòstre senhal",
    "You changed your password" : "Avètz cambiat de senhal",
    "Your password was reset by an administrator" : "Un administrator a reïnicializat vòstre senhal",
    "Your password was reset" : "Qualqu’un a reïnicializat vòstre senhal",
    "{actor} changed your email address" : "{actor} cambièt vòstra adreça email",
    "You changed your email address" : "Avètz cambiat vòstra adreça email",
    "Your email address was changed by an administrator" : "Un administrator cambièt vòstra adreça email",
    "You created app password \"{token}\"" : "Avètz creat lo senhal d’aplicacion « {token} »",
    "You deleted app password \"{token}\"" : "Avètz suprimit lo senhal d’aplicacion « {token} »",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "Avètz renommat lo senhal d’aplicacion « {token} » en « {newToken} »",
    "Security" : "Seguretat",
    "Couldn't remove app." : "Supression impossibla de l’aplicacion.",
    "Couldn't update app." : "Mesa a jorn impossibla de l’aplicacion.",
    "Wrong password" : "Wrong password",
    "Authentication error" : "Error d’autentificacion",
    "Invalid SMTP password." : "Senhal SMTP invalid.",
    "Email setting test" : "Paramètres email de pròva",
    "Well done, %s!" : "Felicitacion, %s !",
    "Invalid user" : "Utilizaire invalid",
    "Invalid mail address" : "Adreça email invalida",
    "Settings saved" : "Paramètres enregistrats",
    "Welcome aboard" : "La benvenguda a bòrd",
    "Welcome aboard %s" : "La benvenguda a bòrd %s",
    "Your username is: %s" : "Vòstre nom d’utilizaire : %s",
    "Set your password" : "Definir vòstre senhal",
    "Go to %s" : "Anar a %s",
    "Install Client" : "Installar client",
    "Apps" : "Aplicacions",
    "Settings" : "Paramètres",
    "Personal" : "Personal",
    "Administration" : "Administracion",
    "Additional settings" : "Paramètres addicionals",
    "Overview" : "Apercebut",
    "Basic settings" : "Paramètres de basa",
    "Sharing" : "Partiment",
    "Personal info" : "Info personalas",
    "Mobile & desktop" : "Mobile e burèu",
    "Create" : "Crear",
    "Change" : "Modificar",
    "Delete" : "Suprimir",
    "Reshare" : "Repartir",
    "Unlimited" : "Illimitat",
    "Verifying" : "Verificacion",
    "Nextcloud settings" : "Paramètres Nextcloud",
    "Limit to groups" : "Limitar als grops",
    "Save changes" : "Enregistrar las modificacions",
    "All" : "Tot",
    "No results" : "Cap de resultat",
    "Update to {version}" : "Metre a jorn cap a {version}",
    "Remove" : "Suprimir",
    "Disable" : "Desactivar",
    "View in store" : "Veire a la botiga",
    "Visit website" : "Veire lo site web",
    "Report a bug" : "Raportar un bug",
    "User documentation" : "Documentacion utilizaire",
    "Admin documentation" : "Documentacion d’admin",
    "Developer documentation" : "Documentacion desvolopaire",
    "Update all" : "Tot metre a jorn",
    "Disable all" : "Desactivar tot",
    "Enable all" : "Activar tot",
    "Device settings" : "Paramètres periferic",
    "Allow filesystem access" : "Permetre accès filesystem",
    "Rename" : "Renomenar",
    "Revoke" : "Revocar",
    "Wipe device" : "Tirar periferic",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome per Android",
    "iPhone" : "iPhone",
    "iPad" : "iPad",
    "Nextcloud iOS app" : "Aplicacion Nextcloud iOS",
    "Nextcloud Talk for iOS" : "Nextcloud Talk per iOS",
    "Nextcloud Talk for Android" : "Nextcloud Talk per Android",
    "This session" : "Aquesta session",
    "Device" : "Periferic",
    "Last activity" : "Darrièra activitat",
    "Devices & sessions" : "Periferics e sessions",
    "App name" : "Nom d’aplicacion",
    "Username" : "Nom d'utilizaire",
    "Password" : "Senhal",
    "Done" : "Done",
    "Copied!" : "Copiat !",
    "Copy" : "Copiar",
    "Add new password" : "Apondre senhal novèl",
    "No language set" : "Cap de lenga pas definida",
    "Delete user" : "Suprimir l’utilizaire",
    "Wipe all devices" : "Escafar totes los periferics",
    "Disable user" : "Desactivar l’utilizaire",
    "Enable user" : "Activar l’utilizaire",
    "Cancel" : "Anullar",
    "Account deletion" : "Supression de compte",
    "Edit User" : "Modificar l’utilizaire",
    "{size} used" : "{size} utilizat",
    "Display name" : "Nom afichat",
    "Email" : "Adreça corrièl",
    "Default language" : "Lenga per defaut",
    "Add a new user" : "Apondre un utilizaire novè",
    "Close" : "Tampar",
    "Language" : "Lenga",
    "Common languages" : "Lengas comunas",
    "All languages" : "Totas las lengas",
    "Name your device" : "Nommatz vòstre periferic",
    "Add" : "Ajustar",
    "Adding your device …" : "Apondon del periferic…",
    "Unnamed device" : "Periferic sens nom",
    "Passwordless Authentication" : "Autentificacion sens senhal",
    "No devices configured." : "Cap de periferic pas configurat.",
    "Your apps" : "Vòstras aplicacions",
    "Active apps" : "Aplicacions activas",
    "Disabled apps" : "Aplicacions desactivadas",
    "Updates" : "Mesas a jorn",
    "Details" : "Detalhs",
    "Changelog" : "Nòta de version",
    "by {author}\n{license}" : "per {author}\n{license}",
    "New user" : "Utilizaire novèl",
    "Enter group name" : "Picatz un nom de grop",
    "Add group" : "Apondre grop",
    "Everyone" : "Tot lo monde",
    "Admins" : "Admins",
    "Disabled users" : "Utilizaires desactivats",
    "Show Languages" : "Veire las lengas",
    "Enable" : "Activar",
    "Never" : "Pas jamais",
    "Documentation" : "Documentacion",
    "None" : "Pas cap",
    "Login" : "Login",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "Servidor email",
    "Open documentation" : "Dobrir la documentacion",
    "Send mode" : "Mòde de mandadís",
    "Encryption" : "Chiframent",
    "Server address" : "Adreça del servidor",
    "Port" : "Pòrt",
    "Credentials" : "Informacions d'identificacion",
    "SMTP Username" : "Utilizaire SMTP",
    "SMTP Password" : "Senhal SMTP",
    "Save" : "Salvar",
    "Test email settings" : "Ensajar los paramètres email",
    "Send email" : "Enviar email",
    "Version" : "Version",
    "Two-Factor Authentication" : "Autentificacion dos factors",
    "Enable encryption" : "Activar lo chiframent",
    "Start migration" : "Començar la migracion",
    "Background jobs" : "Prètzfaches de rèireplan",
    "days" : "jorns",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Desvolopat per la {communityopen}comunautat Nextcloud{linkclose}, lo {githubopen}còdi font{linkclose} es jos licéncia {licenseopen}AGPL{linkclose}.",
    "Like our Facebook page" : "Aimar nòstra pagina Facebook",
    "Follow us on Twitter" : "Nos seguir sus Twitter",
    "Follow us on Mastodon" : "Nos seguir sus Mastodon",
    "Check out our blog" : "Donar un còp d’uèlh a nòstre blòg",
    "Subscribe to our newsletter" : "S’abonar a l’infoletra",
    "Profile picture" : "Imatge de perfil",
    "Upload new" : "Ne mandar un novèl",
    "Select from Files" : "Seleccionar dels fichièrs",
    "Remove image" : "Suprimir imatge",
    "png or jpg, max. 20 MB" : "png or jpg, max. 20 Mo",
    "Picture provided by original account" : "Imatge provesit pel compte d’origina",
    "Choose as profile picture" : "Causir coma imatge de perfil",
    "You are a member of the following groups:" : "Formatz part d’aquestes grops :",
    "You are using <strong>%s</strong>" : "Utilizatz <strong>%s</strong>",
    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "Utilizatz <strong>%1$s</strong> de <strong>%2$s</strong> (<strong>%3$s %%</strong>)",
    "Full name" : "Nom complèt",
    "No display name set" : "Cap de nom d’afichatge pas definit",
    "Your email address" : "Vòstra adreça electronica",
    "No email address set" : "Cap d’adreça pas definida",
    "For password reset and notifications" : "Per reconfigurar lo senhal e recebre las notificacions",
    "Phone number" : "Numèro de telefòn",
    "Your phone number" : "Vòstre numèro de telefòn",
    "Address" : "Adreça",
    "Your postal address" : "Vòstra adreça postala",
    "Website" : "Site web",
    "Link https://…" : "Ligam https://…",
    "Twitter" : "Twitter",
    "Twitter handle @…" : "Escais Twitter @…",
    "Help translate" : "Ajudar a traduire",
    "Locale" : "Varianta lingüistica",
    "Current password" : "Senhal actual",
    "New password" : "Senhal novèl",
    "Change password" : "Cambiar de senhal",
    "Only visible to you" : "Sonque visible per vos",
    "Contacts" : "Contactes",
    "Public" : "Public",
    "by" : "per",
    "Valid until" : "Valid fins a",
    "Issued By" : "Emés per",
    "Valid until %s" : "Valid fins a %s",
    "Don't synchronize to servers" : "Sincronizar pas als servidors",
    "Trusted" : "Fisable"
},
"nplurals=2; plural=(n > 1);");
